pub struct CropIndexDiagnostics {
pub illumination_index: usize,
pub x_start: usize,
pub x_end: usize,
pub y_start: usize,
pub y_end: usize,
pub center_x: f64,
pub center_y: f64,
}Expand description
Pixel bounds and center of one source crop in the high-resolution Fourier grid.
Fields
illumination_index: usizeZero-based individual illumination-source index.
x_start: usizeInclusive first Fourier column (x).
x_end: usizeExclusive last Fourier column (x).
y_start: usizeInclusive first Fourier row (y).
y_end: usizeExclusive last Fourier row (y).
center_x: f64Crop center along the Fourier column axis, in grid pixels.
center_y: f64Crop center along the Fourier row axis, in grid pixels.